import React from 'react';
import getPlaces from '~/business-logic/core/places/get-places';
import getPlacesAdapter from '~/driven/adapters/get-places-adapter/getPlacesAdapter';
import StateManagementService from '~/driven/boundaries/state-management';
import PlacesModel from '~/business-logic/core/places/common/model/placesModel';
import PlacesListView from '../view/PlacesListView';
import usePlacesListVM from '../viewmodel/placesListVM';
import placesListModel from '../model/placesListModel';

const prepareTheLogicForModel = () => {
  const gettingPlacesDrivenAdapter = getPlacesAdapter();
  const { url } = gettingPlacesDrivenAdapter;
  const getingPlacesLogic = getPlaces(gettingPlacesDrivenAdapter);
  return { getingPlacesLogic, url };
};

const prepareStateManagementForVM = (
  apiUrl: string,
  placesModel: () => Promise<PlacesModel>
) => {
  const stateManagement = StateManagementService.swr();

  const useGetPlacesList = () =>
    stateManagement.useGetQuery(apiUrl, placesModel);

  return useGetPlacesList;
};

export default function PlacessList() {
  const { getingPlacesLogic, url } = prepareTheLogicForModel();
  const placesModel = async () => await placesListModel(getingPlacesLogic);

  const useGetPlacesList = prepareStateManagementForVM(url, placesModel);
  const { selectedRowId, setSelectedRowId, placesData } = usePlacesListVM({
    useGetPlacesList,
  });
  return (
    <PlacesListView
      placesList={placesData}
      selectedRowId={selectedRowId}
      setSelectedRowId={setSelectedRowId}
    />
  );
}
